"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.removePackagePnpm = void 0;
const config_1 = __importDefault(require("@pnpm/config"));
const core_1 = require("@pnpm/core");
const read_project_manifest_1 = __importDefault(require("@pnpm/read-project-manifest"));
const store_connection_manager_1 = require("@pnpm/store-connection-manager");
const write_project_manifest_1 = __importDefault(require("@pnpm/write-project-manifest"));
const path_1 = __importDefault(require("path"));
const simplifyPeerDependencyIssues_1 = require("./simplifyPeerDependencyIssues");
const removePackagePnpm = (packages, options) => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b;
    const packagesArray = Array.isArray(packages) ? packages : [packages];
    const directory = (_a = options === null || options === void 0 ? void 0 : options.directory) !== null && _a !== void 0 ? _a : process.cwd();
    const type = (_b = options === null || options === void 0 ? void 0 : options.type) !== null && _b !== void 0 ? _b : "all";
    const { manifest, fileName } = yield (0, read_project_manifest_1.default)(directory);
    const config = yield (0, config_1.default)({
        cliOptions: {
            dir: directory,
        },
        packageManager: {
            name: "yarn",
            version: "4.0.0",
        },
        workspaceDir: directory,
    });
    const storeController = yield (0, store_connection_manager_1.createOrConnectStoreController)(Object.assign(Object.assign({}, config.config), { dir: directory, workspaceDir: directory }));
    const projects = yield (0, core_1.mutateModules)([
        {
            manifest: manifest,
            dependencyNames: packagesArray,
            targetDependenciesField: type === "all"
                ? undefined
                : type === "dev"
                    ? "devDependencies"
                    : type === "optional"
                        ? "optionalDependencies"
                        : "dependencies",
            mutation: "uninstallSome",
            rootDir: directory,
        },
    ], {
        storeDir: storeController.dir,
        storeController: storeController.ctrl,
        useLockfile: true,
        saveLockfile: true,
        fixLockfile: true,
        lockfileDir: directory,
        autoInstallPeers: true,
    });
    yield (0, write_project_manifest_1.default)(path_1.default.resolve(directory, fileName), projects[0].manifest);
    const peerDependencyIssues = projects[0].peerDependencyIssues
        ? (0, simplifyPeerDependencyIssues_1.simplifyPeerDependencyIssues)(projects[0].peerDependencyIssues)
        : [];
    return peerDependencyIssues;
});
exports.removePackagePnpm = removePackagePnpm;
